@@ -9,7 +9,9 @@ from .constants import (
 )
 from .api import (
     RemoteTimestamper, check_timestamp, get_hash_oid,
-    TimestampingError, get_timestamp
+    TimestampingError, get_timestamp, make_timestamp_request,
+    encode_timestamp_request, encode_timestamp_response,
+    decode_timestamp_request, decode_timestamp_response,
 )
 
 __all__ = (
@@ -23,7 +25,9 @@ __all__ = (
     'id_sha512', 'id_ct_TSTInfo', 'oid_to_hash',
 
     'RemoteTimestamper', 'check_timestamp', 'get_hash_oid',
-    'TimestampingError', 'get_timestamp',
+    'TimestampingError', 'get_timestamp', 'make_timestamp_request',
+    'encode_timestamp_request', 'encode_timestamp_response',
+    'decode_timestamp_request', 'decode_timestamp_response',
 )
 
-VERSION = '2.0.3'
+VERSION = '2.1.2'
